<?php
namespace Drupal\instagram_feed_by_username;

use Symfony\Component\DependencyInjection\ContainerInterface;
use GuzzleHttp\ClientInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Component\Render\FormattableMarkup;
use GuzzleHttp\Exception\GuzzleException;
use Drupal\Component\Serialization\Json;
/**
 * The InstaService service class.
 */
class InstagramFeedByUsernameService
{
    /**
     * The HTTP client to fetch the feed data with.
     *
     * @var \GuzzleHttp\ClientInterface
     */
    protected $httpClient;
    /**
     * Constructor for InstaService.
     *
     * @param \GuzzleHttp\ClientInterface $http_client
     *   A Guzzle client object.
     */
    public function __construct(ClientInterface $http_client)
    {
        $this->httpClient = $http_client;
    }
    /**
     * {@inheritdoc}
     */
    public static function create(ContainerInterface $container)
    {
        return new static($container->get("http_client"));
    }
    /**
     * Posts route callback.
     *
     * @param string $userName
     *   For passing the username
     *
     * @return html data
     *   return html data
     */
    public function posts($userName)
    {
        $userInstaFeeds = "";
        try {
            /**
             * We use Guzzle to make an HTTP request.
             */
            $request = $this->httpClient->request(
                "GET",
                "https://api.woxo.tech/instagram?source=" . $userName,
                []
            );
        } catch (GuzzleException $error) {
            /**
             * Here we catch the instance of GuzzleHttp\Psr7\Response
             * So you can have: HTTP status code, message, headers and body.
             * Just check the exception object has the response before.
             */
            $request = $error->getResponse();
            $posts = $request->getBody()->getContents();
            $message = new FormattableMarkup(
                "API connection error. Error details are as follows:<pre>@response</pre>",
                ["@response" => print_r(json_decode($posts), true)]
            );
            watchdog_exception("Remote API Connection", $error, $message);
        }
        // if the response is success
        if ($request->getStatusCode() != 200) {
            return $userInstaFeeds;
        }
        $posts = $request->getBody()->getContents();
        $data = Json::decode($posts);
        $insta_feed = $data;
        if (!empty($data)) {
            // Render output using instagram_feed_by_username theme.
            $renderable = [
                "#theme" => "field__instagram_feed_by_username",
                "#data" => $data,
            ];
            $userInstaFeeds = \Drupal::service("renderer")->renderPlain(
                $renderable
            );
        } else {
            \Drupal::messenger()->addWarning(
                t("Instagram username is not correct")
            );
            $userInstaFeeds = "Cannot find the username";
        }
        $message = new FormattableMarkup(
            "API connection error. Error details are as follows:<pre>@response</pre>",
            ["@response" => print_r(json_decode($posts), true)]
        );
        return $userInstaFeeds;
    }
}
