<?php

namespace Drupal\instagram_feed_by_username\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'InstagramFieldByUsernameFieldFormatter' formatter.
 *
 * @FieldFormatter
 * (
 *   id = "InstagramFieldByUsernameFieldFormatter",
 *   label = @Translation("Instagram username field formatter"),
 *   field_types = {
 *     "instagram_field"
 *   }
 *  )
 */
class InstagramFeedByUsernameFieldFormatter extends FormatterBase
{
    /**
     * Define how the field type is showed.
     *
     * Inside this method we can customize how the field is displayed inside
     * pages.
     */
    /**
     * {@inheritdoc}
     */
    public static function defaultSettings()
    {
        return [
            // Implement default settings.
        ] + parent::defaultSettings();
    }

    /**
     * {@inheritdoc}
     */
    public function settingsSummary()
    {
        $summary = [];
        $summary[] = $this->t("Displays the random string.");
        return $summary;
    }
    /**
     * Builds a renderable array for a field value.
     *
     * @param \Drupal\Core\Field\FieldItemListInterface $items
     *   The field values to be rendered.
     * @param string $langcode
     *   The language that should be used to render the field.
     *
     * @return array
     *   A renderable array for $items, as an array of child elements keyed by
     *   consecutive numeric indexes starting from 0.
     */

    /**
     * {@inheritdoc}
     */
    public function viewElements(FieldItemListInterface $items, $langcode)
    {
        $elements = [];
        $elements["#attached"]["library"][] =
            "instagram_feed_by_username/instagram_feed_by_username";
        $elements["#attributes"]["enctype"] = "multipart/form-data";
        foreach ($items as $delta => $item) {
            // Render output using #markup from instagram_feed_by_username_service.
            $userName = $item->instagram_field;
            $userInstaFeeds = \Drupal::service(
                "instagram_feed_by_username_service"
            )->posts($userName);
            $elements[$delta][] = [
                "#markup" => $userInstaFeeds,
            ];
        }
        return $elements;
    }
}
